#!/ysr/bin/env python
#-*- coding:utf-8 -*-
__author__ = "yua"

import smtplib, os
from email.header import Header
from email.mime.text import MIMEText
from email.utils import formataddr
from email.mime.multipart import MIMEMultipart
from email.mime.application import MIMEApplication

from django.conf import settings

from Service.Logger import logger

class SystemEmail(object):
    def __init__(self, email_addr, email_alias):
        self.email_addr = email_addr
        self.email_alias = email_alias

        self.send_email_addr = settings.EMAIL_CONFIG['send_email_addr']
        self.send_email_alias = settings.EMAIL_CONFIG['send_email_alias']
        self.send_email_key = settings.EMAIL_CONFIG['send_email_key']

    def __get_format_addr(self, name, addr):
        return formataddr((Header(name, 'utf-8').encode(), addr))

    def __get_send_email_server(self):
        obj_server = smtplib.SMTP_SSL(settings.EMAIL_CONFIG['smtp_server'], 465)
        obj_server.login(self.send_email_addr, self.send_email_key)

        return obj_server

    def send_email(self, subject, body, attachment=None):
        try:
            logger.info('发送邮件到 [%s].' %(self.email_addr))
            obj_mime = MIMEMultipart()
            obj_mime['From'] = self.__get_format_addr(self.send_email_alias, self.send_email_addr)
            obj_mime['To'] = self.__get_format_addr(self.email_alias, self.email_addr)
            obj_mime['Subject'] = Header(subject, 'utf-8').encode()

            obj_body = MIMEText(body, 'plain', 'utf-8')
            obj_mime.attach(obj_body)
            if attachment:
                for i in attachment:
                    obj_part = MIMEApplication(open(i, 'rb').read())
                    obj_part.add_header('Content-Disposition', 'attachment', filename=os.path.basename(i))
                    obj_mime.attach(obj_part)

            obj_server = self.__get_send_email_server()
            obj_server.sendmail(self.send_email_addr, [self.email_addr], obj_mime.as_bytes())
            obj_server.quit()
            return True
        except Exception as e:
            logger.error(str(e))
            return False


